NCRAR audio
-----------

To find out what audio devices are installed:

    python -m sounddevice

Copyright notice 

© 2021-2023, ncrar-audio development team

Portions of this project were funded by:

* The National Center for Rehabilitative Auditory Research at the Portland VA Medical Center on contract 36C26021P0557 awarded to Buran Consulting, LLC.
* Various NIH grants to Brad Buran, Stephen David, Naomi Bramhall and other investigators at the Oregon Hearing Research Center.
